# Building AI Applications (Examples)

Llama Stack provides all the building blocks needed to create sophisticated AI applications.

The best way to get started is to look at this notebook which walks through the various APIs (from basic inference, to RAG agents) and how to use them.

**Notebook**: [Building AI Applications](https://github.com/meta-llama/llama-stack/blob/main/docs/getting_started.ipynb)

Here are some key topics that will help you build effective agents:

- **[RAG (Retrieval-Augmented Generation)](rag)**: Learn how to enhance your agents with external knowledge through retrieval mechanisms.
- **[Agent](agent)**: Understand the components and design patterns of the Llama Stack agent framework.
- **[Agent Execution Loop](agent_execution_loop)**: Understand how agents process information, make decisions, and execute actions in a continuous loop.
- **[Tools](tools)**: Extend your agents' capabilities by integrating with external tools and APIs.
- **[Evals](evals)**: Evaluate your agents' effectiveness and identify areas for improvement.
- **[Telemetry](telemetry)**: Monitor and analyze your agents' performance and behavior.
- **[Safety](safety)**: Implement guardrails and safety measures to ensure responsible AI behavior.

```{toctree}
:hidden:
:maxdepth: 1

rag
agent
agent_execution_loop
tools
evals
telemetry
safety
```
